@@ -5,9 +5,8 @@ use crate::{
     mode::Mode,
     util::ExprOptExt,
 };
-use swc_common::{Spanned, DUMMY_SP};
+use swc_common::{util::take::Take, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{prepend, undefined, StmtLike};
 use swc_ecma_visit::{noop_visit_type, Node, Visit, VisitWith};
 
