@@ -2,9 +2,8 @@ use super::Pure;
 use crate::mode::Mode;
 use std::mem::take;
 use swc_atoms::{js_word, JsWord};
-use swc_common::DUMMY_SP;
+use swc_common::{util::take::Take, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ExprExt, Type, Value};
 
 impl<M> Pure<'_, M>
