@@ -2,10 +2,10 @@ use fxhash::FxHashSet;
 use std::time::Instant;
 use swc_common::{
     pass::{CompilerPass, Repeated},
+    util::take::Take,
     Mark, Span, DUMMY_SP,
 };
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ident::IdentLike, Id, ModuleItemLike, StmtLike, Value};
 use swc_ecma_visit::{noop_visit_type, Fold, FoldWith, Node, Visit, VisitWith};
 
